#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-De3f1qSnlIxE9TOjVFJh6X
key:                  pantry-0.8.3-De3f1qSnlIxE9TOjVFJh6X
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  57734db68ab27905ef151009ea85ccab
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-De3f1qSnlIxE9TOjVFJh6X
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    ansi-terminal-1.1-DloTwXdDsLxGyTkENbfyqg base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.4-JOQktMHvd2p1JeZsGTEnWc
    casa-types-0.0.3-CJwxqeXq58c1AWsEBTsxYO
    conduit-1.3.6.1-65VBuodW2FA1U1zRKEX2Oq
    conduit-extra-1.3.8-8C1YMRPmMt82mJiP8UVrWz containers-0.6.7
    crypton-1.0.5-7t0kyZzS7otBofbnZ6zHEy
    crypton-conduit-0.2.3-1xDWfGVCIAAdmniyhCcfL
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.9-FxlQK29YYsT5BJApiYQGhe
    generic-deriving-1.14.7-EdpMS6VUjSWAYwhkxCiLC8
    hackage-security-0.6.3.2-HEgyfacPMNACuceVjwr6rY
    hpack-0.38.0-6zTdnVhly0tI2tqUn0uTtW
    http-client-0.7.19-4FCJ2m94wUmJsssaVohngD
    http-client-tls-0.3.6.4-K9pa9aqIB7M16aJexgoa6z
    http-conduit-2.3.9.1-KDnV8VsG74SBT5pJfJbgZK
    http-download-0.2.1.0-7hVYX15qID7WPw6Wp3sKK
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-1CJs0qlSGKv7cmTNxU9YR0
    path-0.9.6-GztXZKf17iiBydBxqKmqaR
    path-io-1.8.2-4BGDxXhcnF7GZy9alBMQfx
    persistent-2.14.6.1-CXYeTUPLnecB49WmzMNtSU
    persistent-sqlite-2.13.3.0-BAXvqHfzQeuKfxq9f8dtbj
    primitive-0.9.1.0-IuEzc1i7B8w72ArTAK2GO5
    resourcet-1.3.0-HYdPrsWCzneJIcOsQDIVse
    rio-0.1.25.0-A1xmpAj0yy03sIARUcpHUN
    rio-orphans-0.1.2.0-BJESVW7NR3zK7nZxmPH92e
    rio-prettyprint-0.1.9.0-6OLYwOPxftsA6SK0py31NL
    tar-conduit-0.4.1-1KpNU44ibwn3lNJVOopznX text-2.0.2
    text-metrics-0.3.3-5tGUa8zhnfk4dWBT7ycbs0 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-EyHNw9oGSnZGifmmgNTG2S
    unliftio-0.2.25.1-JOKqT5DcdDFKqQgMQFlxcn
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7
    yaml-0.11.11.2-7C8te7oEKag5lil8hT24q7
    zip-archive-0.4.3.2-HOJElStBDZC4LyBWVIWbJN

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

